﻿namespace DemoWebsocket.Client.Pages
{
    using DemoWebsocket.Client.Models;
    using System;
    using System.Collections.Generic;
    using System.Net.WebSockets;
    using System.Text;
    using System.Text.Json;
    using System.Threading;
    using System.Threading.Tasks;

    public partial class DemoNative
    {
        private string connectionUrl = "wss://localhost:44391/ws";
        private CancellationTokenSource disposalTokenSource = new CancellationTokenSource();
        private List<Chat> logs = new List<Chat>();
        private string message = "";
        private string userName = "UserName";
        private ClientWebSocket webSocket = new ClientWebSocket();

        public async void Dispose()
        {
            await SendAsync(new Chat { Type = "disconnect", Name = userName });

            disposalTokenSource.Cancel();
            _ = webSocket.CloseAsync(WebSocketCloseStatus.NormalClosure, "Bye", CancellationToken.None);
        }

        private async void OnClose()
        {
            await SendAsync(new Chat { Type = "disconnect", Name = userName });

            disposalTokenSource.Cancel();
            _ = webSocket.CloseAsync(WebSocketCloseStatus.NormalClosure, "Bye", CancellationToken.None);
        }

        private async void OnConnect()
        {
            await webSocket.ConnectAsync(new Uri(connectionUrl), disposalTokenSource.Token);
            await SendAsync(new Chat { Type = "connect", Name = userName });

            _ = ReceiveLoop();
        }

        private async Task ReceiveLoop()
        {
            var buffer = new ArraySegment<byte>(new byte[1024]);
            while (!disposalTokenSource.IsCancellationRequested)
            {
                var received = await webSocket.ReceiveAsync(buffer, disposalTokenSource.Token);
                var receivedAsText = Encoding.UTF8.GetString(buffer.Array, 0, received.Count);

                var chat = JsonSerializer.Deserialize<Chat>(receivedAsText);

                logs.Add(chat);

                StateHasChanged();
            }
        }

        private async Task SendAsync(Chat chat)
        {
            var data = JsonSerializer.Serialize(chat);
            var dataToSend = new ArraySegment<byte>(Encoding.UTF8.GetBytes(data));
            await webSocket.SendAsync(dataToSend, WebSocketMessageType.Text, true, disposalTokenSource.Token);
        }

        private async Task SendMessageAsync()
        {
            await SendAsync(new Chat { Type = "message", Name = userName, Message = message });
        }
    }
}