﻿
window.JsWebsocket =
{
    init: function () {

        var connectionUrl = document.getElementById("connectionUrl");
        var connectButton = document.getElementById("connectButton");
        var stateLabel = document.getElementById("stateLabel");
        var sendMessage = document.getElementById("sendMessage");
        var sendButton = document.getElementById("sendButton");
        var commsLog = document.getElementById("commsLog");
        var closeButton = document.getElementById("closeButton");
        var userName = document.getElementById("userName");
        var socket;

        connectionUrl.value = "wss://localhost:44391/ws";
        
        function updateState() {
            function disable() {
                sendMessage.disabled = true;
                sendButton.disabled = true;
                closeButton.disabled = true;
            }
            function enable() {
                sendMessage.disabled = false;
                sendButton.disabled = false;
                closeButton.disabled = false;
            }

            connectionUrl.disabled = true;
            connectButton.disabled = true;

            if (!socket) {
                disable();
            } else {
                switch (socket.readyState) {
                    case WebSocket.CLOSED:
                        stateLabel.innerHTML = "Closed";
                        disable();
                        connectionUrl.disabled = false;
                        connectButton.disabled = false;
                        break;
                    case WebSocket.CLOSING:
                        stateLabel.innerHTML = "Closing...";
                        disable();
                        break;
                    case WebSocket.CONNECTING:
                        stateLabel.innerHTML = "Connecting...";
                        disable();
                        break;
                    case WebSocket.OPEN:
                        stateLabel.innerHTML = "Open";
                        enable();
                        break;
                    default:
                        stateLabel.innerHTML = "Unknown WebSocket State: " + htmlEscape(socket.readyState);
                        disable();
                        break;
                }
            }
        }


        closeButton.onclick = function () {
            if (!socket || socket.readyState !== WebSocket.OPEN) {
                alert("socket not connected");
            }

            // Send message to user disconnected
            socket.send(JSON.stringify({ 'type': 'disconnect', 'name': userName.value }));

            socket.close(1000, "Closing from client");
        };



        sendButton.onclick = function () {
            if (!socket || socket.readyState !== WebSocket.OPEN) {
                alert("socket not connected");
            }
            
            socket.send(JSON.stringify({ 'type': 'message', 'name': userName.value, 'message': sendMessage.value }));
        };

        connectButton.onclick = function () {
            stateLabel.innerHTML = "Connecting";
            socket = new WebSocket(connectionUrl.value);
            socket.onopen = function (event) {
                updateState();

                // Send message to user connected
                socket.send(JSON.stringify({ 'type': 'connect', 'name': userName.value }));
            };
            socket.onclose = function (event) {
                updateState();
            };
            socket.onerror = updateState;
            socket.onmessage = function (event) {
                var data = JSON.parse(event.data);

                switch (data.type) {
                    case 'connect':
                        commsLog.innerHTML += '<div>L\'utilisateur ' + htmlEscape(data.name) + ' vient de se connecter.</div>';
                        break;
                    case 'disconnect':
                        commsLog.innerHTML += '<div>L\'utilisateur ' + htmlEscape(data.name) + ' vient de se déconnecter.</div>';
                        break;
                    case 'message':
                        commsLog.innerHTML += '<div>' + htmlEscape(data.name) + ': ' + htmlEscape(data.message) + '</div>';
                        break;

                    default:
                        commsLog.innerHTML += '<div>Unknow message type ! - ' + htmlEscape(event.data) + '</div>';
                        break;
                }
            };
        };
    }
};

function htmlEscape(str) {
    return str.toString()
        .replace(/&/g, '&amp;')
        .replace(/"/g, '&quot;')
        .replace(/'/g, '&#39;')
        .replace(/</g, '&lt;')
        .replace(/>/g, '&gt;');
}