namespace DemoWebsocket.Server
{
    using DemoWebsocket.Server.Hubs;
    using DemoWebsocket.Server.WebSockets;
    using Microsoft.AspNetCore.Builder;
    using Microsoft.AspNetCore.Hosting;
    using Microsoft.Extensions.DependencyInjection;
    using Microsoft.Extensions.Hosting;

    public class Startup
    {
        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }

            app.UseDefaultFiles();
            app.UseStaticFiles();

            app.UseWebSocket<ChatConsumerHandler>();

            app.UseRouting();

            app.UseCors("DefaultPolicy");

            app.UseEndpoints(endpoints =>
            {
                endpoints.MapHub<ChatHub>("/chatHub");
            });
        }

        public void ConfigureServices(IServiceCollection services)
        {
            services.AddCors(options =>
            {
                options.AddPolicy("DefaultPolicy", builder =>
                {
                    // Do not use this in production
                    builder
                       .AllowAnyHeader()
                       .AllowAnyMethod()
                       .AllowAnyOrigin();
                });
            });

            // For Websocket
            services.AddWebSockets();

            // For SignalR
            services.AddSignalR();
        }
    }
}