﻿namespace MyBeautifulAdmin.Components
{
    using Microsoft.AspNetCore.Components;

    public partial class MinesweeperCell
    {
        private bool _revealed;

        private int _value = 0;

        public MinesweeperCell()
        {
            GenerateStyle();
        }

        [CascadingParameter]
        public Minesweeper Parent { get; set; }

        [Parameter]
        public bool Revealed
        {
            get => _revealed;
            set
            {
                if (this._revealed == value)
                {
                    return;
                }

                this._revealed = value;
                this.OnRevealedChanged();
                this.StateHasChanged();
            }
        }

        [Parameter]
        public int Value
        {
            get => _value;
            set
            {
                if (this._value == value)
                {
                    return;
                }

                this._value = value;
                this.OnValueChanged();
                this.StateHasChanged();
            }
        }

        [Parameter]
        public int X { get; set; }

        [Parameter]
        public int Y { get; set; }

        internal string CellStyle { get; set; }

        internal string Display { get; set; }

        public void GenerateDisplay()
        {
            this.Display = !Revealed || Value is 0 ? " " : Value is Minesweeper.MineValue ? "X" : Value.ToString();
        }

        public void GenerateStyle()
        {
            CellStyle = "cell";

            if (Revealed && Value is not 0)
            {
                CellStyle += " danger";
            }

            if (Revealed && Value is 0)
            {
                CellStyle += " safe";
            }

            if (Revealed && Value is Minesweeper.MineValue)
            {
                CellStyle += " mine";
            }
        }

        public void OnRevealedChanged()
        {
            GenerateStyle();
            GenerateDisplay();
        }

        public void OnValueChanged()
        {
            GenerateStyle();
            GenerateDisplay();
        }

        private void ClickCell()
        {
            if (Value is Minesweeper.MineValue)
            {
                Parent.RevealAll();

                StateHasChanged();
                return;
            }

            Parent.Reveal(X, Y);

            StateHasChanged();
        }
    }
}