﻿namespace MyBeautifulApi.Controllers
{
    using Entities;
    using Microsoft.AspNetCore.Mvc;
    using MyBeautifulModel;
    using System;
    using System.Collections.Generic;
    using System.Linq;

    [ApiController]
    [Route("[controller]")]
    public class MovieController : ControllerBase
    {
        [HttpPost]
        [Route("")]
        public int Add(MovieModel movie)
        {
            using (var dbContext = new MovieDbContext())
            {
                var entity = new Movie
                {
                    Title = movie.Title,
                    Year = movie.Year
                };

                dbContext.Movies.Add(entity);

                dbContext.SaveChanges();

                return entity.Id;
            }
        }

        [HttpGet]
        [Route("count")]
        public int Count()
        {
            using (var dbContext = new MovieDbContext())
            {
                return dbContext.Movies.Count();
            }
        }

        [HttpDelete]
        [Route("{id}")]
        public void Delete(int id)
        {
            using (var dbContext = new MovieDbContext())
            {
                var entity = dbContext.Movies.FirstOrDefault(w => w.Id == id);

                if (entity == null)
                {
                    throw new Exception($"The movie with id: {id} is not found !");
                }

                dbContext.Movies.Remove(entity);
                dbContext.SaveChanges();
            }
        }

        [HttpGet]
        [Route("")]
        public IEnumerable<MovieModel> Get(
            [FromQuery] int pageNumber,
            [FromQuery] int pageSize)
        {
            if (pageNumber == 0)
            {
                pageNumber = 1;
            }

            if (pageSize == 0)
            {
                pageSize = 1000;
            }

            using (var dbContext = new MovieDbContext())
            {
                return dbContext.Movies
                   .Skip((pageNumber - 1) * pageSize)
                   .Take(pageSize)
                   .ToList()
                   .Select(s => new MovieModel
                   {
                       Id = s.Id,
                       Title = s.Title,
                       Year = s.Year
                   });
            }
        }

        [HttpGet]
        [Route("{id}")]
        public MovieModel GetById(int id)
        {
            using (var dbContext = new MovieDbContext())
            {
                var entity = dbContext.Movies.FirstOrDefault(w => w.Id == id);

                if (entity == null)
                {
                    throw new Exception($"The movie with id: {id} is not found !");
                }

                return new MovieModel
                {
                    Id = entity.Id,
                    Title = entity.Title,
                    Year = entity.Year
                };
            }
        }

        [HttpPut]
        [Route("")]
        public void Update(MovieModel movie)
        {
            using (var dbContext = new MovieDbContext())
            {
                var entity = dbContext.Movies.FirstOrDefault(w => w.Id == movie.Id);

                if (entity == null)
                {
                    throw new Exception($"The movie with id: {movie.Id} is not found !");
                }

                entity.Title = movie.Title;
                entity.Year = movie.Year;

                dbContext.Update(entity);
                dbContext.SaveChanges();
            }
        }
    }
}