﻿namespace MyBeautifulCaller
{
    using MyBeautifulModel;
    using RestSharp;
    using RestSharp.Serializers.SystemTextJson;
    using System;
    using System.Collections.Generic;

    internal class Program
    {
        private const string ApiUri = "https://localhost:44393";

        internal static void Main(string[] args)
        {
            Get();

            Get(2, 10);

            GetById(15724);

            var newId = Add(new MovieModel { Title = "MyBeautifulMovie", Year = DateTime.Now.Year });
            GetById(newId);

            Update(new MovieModel { Id = newId, Title = "MyBeautifulMovieModified", Year = DateTime.Now.Year + 1 });

            Delete(newId);

            try
            {
                GetById(newId);
            }
            catch (Exception e)
            {
                Console.WriteLine(e);
            }
        }

        private static int Add(MovieModel model)
        {
            var client = new RestClient(ApiUri);
            client.UseSystemTextJson();

            var request = new RestRequest("Movie/").AddJsonBody(model);

            var response = client.Post<int>(request);

            if (!response.IsSuccessful)
            {
                throw new Exception("!IsSuccessful");
            }

            Console.WriteLine("Result of Add");

            Console.WriteLine($"New Id: {response.Data}");

            return response.Data;
        }

        private static void Delete(int id)
        {
            var client = new RestClient(ApiUri);
            var request = new RestRequest("Movie/{id}").AddUrlSegment("id", id);
            var response = client.Delete(request);

            if (!response.IsSuccessful)
            {
                throw new Exception("!IsSuccessful");
            }

            Console.WriteLine("Delete successfully");
        }

        private static void Get()
        {
            var client = new RestClient(ApiUri);

            var request = new RestRequest("Movie/");
            var response = client.Get<List<MovieModel>>(request);

            if (!response.IsSuccessful)
            {
                throw new Exception("!IsSuccessful");
            }

            Console.WriteLine("Result of Get:");

            foreach (var item in response.Data)
            {
                Console.WriteLine($"Id: {item.Id} - Title: {item.Title} - Year: {item.Year}");
            }
        }

        private static void Get(int pageNumber, int pageSize)
        {
            var client = new RestClient(ApiUri);

            var request = new RestRequest("Movie/");
            request.AddQueryParameter("pageNumber", pageNumber.ToString());
            request.AddQueryParameter("pageSize", pageSize.ToString());

            var response = client.Get<List<MovieModel>>(request);

            if (!response.IsSuccessful)
            {
                throw new Exception("!IsSuccessful");
            }

            Console.WriteLine("Result of Get:");

            foreach (var item in response.Data)
            {
                Console.WriteLine($"Id: {item.Id} - Title: {item.Title} - Year: {item.Year}");
            }
        }

        private static void GetById(int id)
        {
            var client = new RestClient(ApiUri);
            var request = new RestRequest("Movie/{id}").AddUrlSegment("id", id);
            var response = client.Get<MovieModel>(request);

            if (!response.IsSuccessful)
            {
                throw new Exception("!IsSuccessful");
            }

            Console.WriteLine("Result of Get:");

            Console.WriteLine($"Id: {response.Data.Id} - Title: {response.Data.Title} - Year: {response.Data.Year}");
        }

        private static void Update(MovieModel model)
        {
            var client = new RestClient(ApiUri);
            client.UseSystemTextJson();

            var request = new RestRequest("Movie/").AddJsonBody(model);

            var response = client.Put(request);

            if (!response.IsSuccessful)
            {
                throw new Exception("!IsSuccessful");
            }

            Console.WriteLine("Update successfully");
        }
    }
}