---
sidebar_position: 7
title: Redirection
---

## Effectuer une redirection

Maintenant que vous pouvez ajouter un élement, il serait interressant de rediriger l'utilisateur vers la liste lors de son ajout.

Ouvrez le fichier `Pages/Add.razor.cs` et ajouter les lignes en surbrillances :

```csharp title="Pages/Add.razor.cs"
public partial class Add
{
	...

// highlight-start
	[Inject]
	public NavigationManager NavigationManager { get; set; }
// highlight-end

	...
	
	private async void HandleValidSubmit()
	{
		...

		// Save the data
		await LocalStorage.SetItemAsync("data", currentData);

// highlight-next-line
        NavigationManager.NavigateTo("list");
	}
}
```

## Notion : Uri et assistance d’état de navigation

Le `NavigationManager` permet de gérer les URI et la navigation dans le code C#. Le `NavigationManager` fournit l’événement et les méthodes indiqués dans le tableau suivant.

| Membre | Description |
| ---- | ---- |
| Uri | Obtient l’URI absolu actuel. |
| BaseUri | Obtient l’URI de base (avec une barre oblique de fin) qui peut être prépendée aux chemins d’URI relatifs pour produire un URI absolu. En règle générale, `BaseUri` correspond à l’attribut `href` de l’élément `<base>` du document dans `wwwroot/index.html` (Blazor WebAssembly) ou `Pages/_Layout.cshtml` (Blazor Server). |
| NavigateTo | Accède à l’URI spécifié. Si `forceLoad` est à la valeur `true`: <ul><li>Le routage côté client est contourné.</li><li>Le navigateur est forcé de charger la nouvelle page à partir du serveur, que l’URI soit normalement géré par le routeur côté client.</li></ul>Si `replace` est à la valeur `true`, l’URI actuel de l’historique du navigateur est remplacé au lieu d’envoyer un nouvel URI sur la pile d’historiques. |
| LocationChanged | Événement qui se déclenche lorsque l’emplacement de navigation a changé. |
| ToAbsoluteUri | Convertit un URI relatif en URI absolu. |
| ToBaseRelativePath | Étant donné un URI de base (par exemple, un URI précédemment retourné par BaseUri), convertit un URI absolu en URI par rapport au préfixe d’URI de base. |
| GetUriWithQueryParameter | Retourne un URI construit en mettant à jour avec un seul paramètre ajouté, mis à jour `NavigationManager.Uri` ou supprimé. |
