---
sidebar_position: 2
title: Modification du service de données
---

Afin de prendre en compte la supression d'un élement, nous allons premier ajouter cette fonctionnalité à notre service de données.

## Ajouter la méthode à l'interface

Ouvrer le fichier `Services/IDataService.cs` et ajouter l'élement en surbrillance :

```csharp title="Services/IDataService.cs"
public interface IDataService
{
	Task Add(ItemModel model);

	Task<int> Count();

	Task<List<Item>> List(int currentPage, int pageSize);

	Task<Item> GetById(int id);
	
	Task Update(int id, ItemModel model);

// highlight-start	
	Task Delete(int id);
// highlight-end
}
```

## Ajouter la méthode à l'implémentation

Ouvrer le fichier `Services/DataLocalService.cs` et ajouter la méthode suivante :

```csharp title="Services/DataLocalService.cs"
...

public async Task Delete(int id)
{
	// Get the current data
	var currentData = await _localStorage.GetItemAsync<List<Item>>("data");

	// Get the item int the list
	var item = currentData.FirstOrDefault(w => w.Id == id);

	// Delete item in
	currentData.Remove(item);

	// Delete the image
	var imagePathInfo = new DirectoryInfo($"{_webHostEnvironment.WebRootPath}/images");
	var fileName = new FileInfo($"{imagePathInfo}/{item.Name}.png");

	if (fileName.Exists)
	{
		File.Delete(fileName.FullName);
	}

	// Save the data
	await _localStorage.SetItemAsync("data", currentData);
}
```