---
sidebar_position: 7
title: Utilisation du composant
---

Maintenant que notre composant est fonctionnel, nous n'avons plus qu'à l'utiliser, pour cela il suffit simplement de le déclarer dans notre page `Pages/Index.razor` avec un jeu de données.

## Ajouter une méthode dans le service de données

Ouvrez l'interface du service et ajoutez une nouvelle méthode pour obtenir les recettes.

```csharp title="Services/IDataService.cs"
public interface IDataService
{
	Task Add(ItemModel model);

	Task<int> Count();

	Task<List<Item>> List(int currentPage, int pageSize);
	
	Task<Item> GetById(int id);

	Task Update(int id, ItemModel model);

	Task Delete(int id);

// highlight-next-line
	Task<List<CraftingRecipe>> GetRecipes();
}
```

## Ajouter une méthode au service local

Ouvrez le service local et implementer la nouvelle méthode pour obtenir les recettes.

```csharp title="Services/DataLocalService.cs"
public class DataLocalService : IDataService
{

	...

	public Task<List<CraftingRecipe>> GetRecipes()
	{
		var items = new List<CraftingRecipe>
		{
			new CraftingRecipe
			{
				Give = new Item { DisplayName = "Diamond", Name = "diamond" },
				Have = new List<List<string>>
				{
					new List<string> { "dirt", "dirt", "dirt" },
					new List<string> { "dirt", null, "dirt" },
					new List<string> { "dirt", "dirt", "dirt" }
				}
			}
		};

		return Task.FromResult(items);
	}
}
```

## Déclaration du composant

```cshtml title="Pages/Index.razor"
<div>
    <Crafting Items="Items" Recipes="Recipes" />
</div>
```

```csharp title="Pages/Index.razor.cs"
public partial class Index
{
	[Inject]
	public IDataService DataService { get; set; }

	public List<Item> Items { get; set; } = new List<Item>();

	private List<CraftingRecipe> Recipes { get; set; } = new List<CraftingRecipe>();

	protected override async Task OnAfterRenderAsync(bool firstRender)
	{
		base.OnAfterRenderAsync(firstRender);

		if (!firstRender)
		{
			return;
		}

		Items = await DataService.List(0, await DataService.Count());
		Recipes = await DataService.GetRecipes();

        StateHasChanged();
	}
}
```

## Importer des fichiers JavaScript

Le composant s'affiche mais les actions utilisateurs ne s'affiche pas, tout simplement car nous n'avons pas importé le fichier JavaScript de celui-ci.

Ouvrir le fichier `Pages/_Layout.cshtml` est ajouter la balise de script suivante :

```cshtml title="Pages/_Layout.cshtml"
...

<script src="Components/Crafting.razor.js"></script>

...
```